@@ -1,5 +1,7 @@
 from .models import User
 from .models import Users
+from .models import Membership
+from .models import Memberships
 from .models import Project
 from .models import Projects
 from .models import UserStory
@@ -16,6 +18,8 @@ from .models import UserStoryStatus
 from .models import UserStoryStatuses
 from .models import Severity
 from .models import Severities
+from .models import Role
+from .models import Roles
 from .models import Priority
 from .models import Priorities
 from .models import IssueStatus
@@ -42,5 +46,5 @@ __all__ = [
     'IssueStatuses', 'TaskStatus', 'TaskStatuses', 'WikiPage', 'WikiPages',
     'WikiLink', 'WikiLinks', 'IssueAttribute', 'IssueAttributes',
     'TaskAttribute', 'TaskAttributes', 'UserStoryAttribute',
-    'UserStoryAttributes'
+    'UserStoryAttributes', 'Membership', 'Memberships', 'Role', 'Roles'
 ]
