@@ -71,6 +71,24 @@ class Users(ListResource):
     instance = User
 
 
+class Membership(InstanceResource):
+
+    endpoint = 'memberships'
+
+    allowed_params = ['email', 'role', 'project']
+
+    repr_attribute = 'email'
+
+
+class Memberships(ListResource):
+
+    instance = Membership
+
+    def create(self, project, email, role, **attrs):
+        attrs.update({'project': project, 'email': email, 'role': role})
+        return self._new_resource(payload=attrs)
+
+
 class Priority(InstanceResource):
 
     endpoint = 'priorities'
@@ -433,6 +451,22 @@ class Severities(ListResource):
         return self._new_resource(payload=attrs)
 
 
+class Role(InstanceResource):
+
+    endpoint = 'roles'
+
+    allowed_params = ['name', 'slug', 'order', 'computable']
+
+
+class Roles(ListResource):
+
+    instance = Role
+
+    def create(self, project, name, **attrs):
+        attrs.update({'project': project, 'name': name})
+        return self._new_resource(payload=attrs)
+
+
 class Project(InstanceResource):
 
     endpoint = 'projects'
@@ -452,6 +486,7 @@ class Project(InstanceResource):
         'issue_types': IssueTypes,
         'task_statuses': TaskStatuses,
         'severities': Severities,
+        'roles': Roles,
         'points': Points,
         'us_statuses': UserStoryStatuses
     }
@@ -477,6 +512,14 @@ class Project(InstanceResource):
         )
         return self
 
+    def add_membership(self, email, role, **attrs):
+        return Memberships(self.requester).create(
+            self.id, email, role, **attrs
+        )
+
+    def list_memberships(self):
+        return Memberships(self.requester).list(project=self.id)
+
     def add_user_story(self, subject, **attrs):
         return UserStories(self.requester).create(
             self.id, subject, **attrs
@@ -534,6 +577,12 @@ class Project(InstanceResource):
     def list_severities(self):
         return Severities(self.requester).list(project=self.id)
 
+    def add_role(self, name, **attrs):
+        return Roles(self.requester).create(self.id, name, **attrs)
+
+    def list_roles(self):
+        return Roles(self.requester).list(project=self.id)
+
     def add_priority(self, name, **attrs):
         return Priorities(self.requester).create(self.id, name, **attrs)
 
